@@ -3,17 +3,18 @@ BEGIN {
   $Dist::Zilla::Plugin::Run::Role::Runner::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $Dist::Zilla::Plugin::Run::Role::Runner::VERSION = '0.007';
+  $Dist::Zilla::Plugin::Run::Role::Runner::VERSION = '0.008';
 }
 # ABSTRACT: Role for the packages of Dist::Zilla::Plugin::Run
 use Moose::Role;
 use String::Formatter 0.102082 ();
 use namespace::autoclean;
+use IPC::Open3 (); # core
 
 has run => (
-	is => 'ro',
-	isa  => 'ArrayRef',
-	default => sub { [] },
+    is => 'ro',
+    isa  => 'ArrayRef',
+    default => sub { [] },
 );
 
 around BUILDARGS => sub {
@@ -30,19 +31,28 @@ around BUILDARGS => sub {
 };
 
 sub call_script {
-	my ( $self, $params ) = @_;
+    my ( $self, $params ) = @_;
 
     foreach my $run_cmd (@{$self->run}) {
 
         if ($run_cmd) {
             my $command = $self->build_formatter($params)->format($run_cmd);
-		$self->log("Executing: ".$command);
-		my $output = `$command`;
-		my $status = $?;
-		$self->log($output);
-		$self->log_fatal("Errorlevel ".$status." on command execute") if $status;
-		$self->log("command executed successful");
+            $self->log("Executing: $command");
 
+            # autoflush STDOUT so we can see command output right away
+            $| = 1;
+            # combine stdout and stderr for ease of proxying through the logger
+            my $pid = IPC::Open3::open3(my ($in, $out), undef, $command);
+            while(defined(my $line = <$out>)){
+                chomp($line); # logger appends its own newline
+                $self->log($line);
+            }
+            # zombie repellent
+            waitpid($pid, 0);
+            my $status = $? >> 8;
+
+            $self->log_fatal("Command exited with status $status") if $status;
+            $self->log("Command executed successfully");
         }
     } 
 }
@@ -79,6 +89,7 @@ sub build_formatter {
 
 
 1;
+# vim: set ts=4 sts=4 sw=4 expandtab smarttab:
 
 __END__
 =pod
@@ -89,7 +100,7 @@ Dist::Zilla::Plugin::Run::Role::Runner - Role for the packages of Dist::Zilla::P
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 DESCRIPTION
 
